//importing packages
import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  curveBasis
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');
//defining X-axis
const render = data => {
  const xValue = d => d.year;
  const xAxisLabel = 'Year';
//labeling band defining Y-axis
  
  const yValue = d => d.Estimated_Deaths;
  const circleRadius = 6;
  const yAxisLabel = 'Estimated Deaths';
  //styles of plot
  const margin = { top: 60, right: 40, bottom: 88, left: 105 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0,innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(20);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(20);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -70)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 50)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  //line graph genertor
  const lineGenerator = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue(d)))
 	  .curve(curveBasis);
  
  g.append('path')
      .attr('class', 'line-path')
      .attr('d', lineGenerator(data));
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};
//gist data(URL)
csv('https://gist.githubusercontent.com/gayatrisirisha/18bcbddfb628174826183525476d6e76/raw/48aa7d508d7def56d8383c8121f6b8f7a4f44514/earthquakes.csv')
  .then(data => {
    data.forEach(d => {
      d.Estimated_Deaths = +d.Estimated_Deaths;
      d.year = +d.year;
    });
    render(data);
  });